==> zzyj-outputvalcount-api-3.0.0-20240708.012125-309-sources.jar: com/ejianc/business/outputvalcount/vo/TargetLrlReportVO.java <==
package com.ejianc.business.outputvalcount.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * TargetLrlReportVO
 *
 * @author generator
 *
 */
public class TargetLrlReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long aid; // 主键ID
    private String billcode; //
    private Long pid; //
    private String pcode; //
    private String pname; //
    private Long orgid; //
    private String orgname; //
    private String porname; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ctime; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date createTime; //
    private Integer xfllv; //
    private BigDecimal contractmny; //
    private BigDecimal noinpromny; //
    private BigDecimal xfl; //
    private BigDecimal mbmny; //
    private BigDecimal rgfcostmny; //
    private BigDecimal clfcostmny; //
    private BigDecimal sbfcostmny; //
    private BigDecimal zyfbcostmny; //
    private BigDecimal qtzccostmny; //
    private BigDecimal jjfcostmny; //
    private BigDecimal sjcostmny; //
    private BigDecimal zhijiefeiheji; //
    private BigDecimal zhijiefeizhanshigonghetonge; //

    private Long engineeringTypeId; //


    public BigDecimal getZhijiefeizhanshigonghetonge() {
        return zhijiefeizhanshigonghetonge;
    }

    public void setZhijiefeizhanshigonghetonge(BigDecimal zhijiefeizhanshigonghetonge) {
        this.zhijiefeizhanshigonghetonge = zhijiefeizhanshigonghetonge;
    }

    public Long getAid() {
        return aid;
    }

    public void setAid(Long aid) {
        this.aid = aid;
    }

    public String getBillcode() {
        return billcode;
    }

    public void setBillcode(String billcode) {
        this.billcode = billcode;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getPcode() {
        return pcode;
    }

    public void setPcode(String pcode) {
        this.pcode = pcode;
    }

    public String getPname() {
        return pname;
    }

    public void setPname(String pname) {
        this.pname = pname;
    }

    public Long getOrgid() {
        return orgid;
    }

    public void setOrgid(Long orgid) {
        this.orgid = orgid;
    }

    public String getOrgname() {
        return orgname;
    }

    public void setOrgname(String orgname) {
        this.orgname = orgname;
    }

    public String getPorname() {
        return porname;
    }

    public void setPorname(String porname) {
        this.porname = porname;
    }

    public Date getCtime() {
        return ctime;
    }

    public void setCtime(Date ctime) {
        this.ctime = ctime;
    }

    @Override
    public Date getCreateTime() {
        return createTime;
    }

    @Override
    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Integer getXfllv() {
        return xfllv;
    }

    public void setXfllv(Integer xfllv) {
        this.xfllv = xfllv;
    }

    public BigDecimal getContractmny() {
        return contractmny;
    }

    public void setContractmny(BigDecimal contractmny) {
        this.contractmny = contractmny;
    }

    public BigDecimal getNoinpromny() {
        return noinpromny;
    }

    public void setNoinpromny(BigDecimal noinpromny) {
        this.noinpromny = noinpromny;
    }

    public BigDecimal getXfl() {
        return xfl;
    }

    public void setXfl(BigDecimal xfl) {
        this.xfl = xfl;
    }

    public BigDecimal getMbmny() {
        return mbmny;
    }

    public void setMbmny(BigDecimal mbmny) {
        this.mbmny = mbmny;
    }

    public BigDecimal getRgfcostmny() {
        return rgfcostmny;
    }

    public void setRgfcostmny(BigDecimal rgfcostmny) {
        this.rgfcostmny = rgfcostmny;
    }

    public BigDecimal getClfcostmny() {
        return clfcostmny;
    }

    public void setClfcostmny(BigDecimal clfcostmny) {
        this.clfcostmny = clfcostmny;
    }

    public BigDecimal getSbfcostmny() {
        return sbfcostmny;
    }

    public void setSbfcostmny(BigDecimal sbfcostmny) {
        this.sbfcostmny = sbfcostmny;
    }

    public BigDecimal getZyfbcostmny() {
        return zyfbcostmny;
    }

    public void setZyfbcostmny(BigDecimal zyfbcostmny) {
        this.zyfbcostmny = zyfbcostmny;
    }

    public BigDecimal getQtzccostmny() {
        return qtzccostmny;
    }

    public void setQtzccostmny(BigDecimal qtzccostmny) {
        this.qtzccostmny = qtzccostmny;
    }

    public BigDecimal getJjfcostmny() {
        return jjfcostmny;
    }

    public void setJjfcostmny(BigDecimal jjfcostmny) {
        this.jjfcostmny = jjfcostmny;
    }

    public BigDecimal getSjcostmny() {
        return sjcostmny;
    }

    public void setSjcostmny(BigDecimal sjcostmny) {
        this.sjcostmny = sjcostmny;
    }

    public BigDecimal getZhijiefeiheji() {
        return zhijiefeiheji;
    }

    public void setZhijiefeiheji(BigDecimal zhijiefeiheji) {
        this.zhijiefeiheji = zhijiefeiheji;
    }

    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
}

==> zzyj-outputvalcount-api-3.0.0-20250611.235814-373-sources.jar: com/ejianc/business/outputvalcount/vo/TargetLrlReportVO.java <==
package com.ejianc.business.outputvalcount.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * TargetLrlReportVO
 *
 * @author generator
 *
 */
public class TargetLrlReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Long cid; // 主键ID
    private Long aid; // 主键ID
    private String billcode; //
    private Long pid; //
    private String pcode; //
    private String pname; //
    private Long orgid; //
    private String orgname; //
    private String porname; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ctime; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date createTime; //
    private Integer xfllv; //
    private BigDecimal contractmny; //
    private BigDecimal noinpromny; //
    private BigDecimal xfl; //
    private BigDecimal mbmny; //
    private BigDecimal rgfcostmny; //
    private BigDecimal clfcostmny; //
    private BigDecimal sbfcostmny; //
    private BigDecimal zyfbcostmny; //
    private BigDecimal qtzccostmny; //
    private BigDecimal jjfcostmny; //
    private BigDecimal sjcostmny; //
    private BigDecimal zhijiefeiheji; //
    private BigDecimal zhijiefeizhanshigonghetonge; //

    private Long engineeringTypeId; //

    public Long getCid() {
        return cid;
    }

    public void setCid(Long cid) {
        this.cid = cid;
    }

    public BigDecimal getZhijiefeizhanshigonghetonge() {
        return zhijiefeizhanshigonghetonge;
    }

    public void setZhijiefeizhanshigonghetonge(BigDecimal zhijiefeizhanshigonghetonge) {
        this.zhijiefeizhanshigonghetonge = zhijiefeizhanshigonghetonge;
    }

    public Long getAid() {
        return aid;
    }

    public void setAid(Long aid) {
        this.aid = aid;
    }

    public String getBillcode() {
        return billcode;
    }

    public void setBillcode(String billcode) {
        this.billcode = billcode;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getPcode() {
        return pcode;
    }

    public void setPcode(String pcode) {
        this.pcode = pcode;
    }

    public String getPname() {
        return pname;
    }

    public void setPname(String pname) {
        this.pname = pname;
    }

    public Long getOrgid() {
        return orgid;
    }

    public void setOrgid(Long orgid) {
        this.orgid = orgid;
    }

    public String getOrgname() {
        return orgname;
    }

    public void setOrgname(String orgname) {
        this.orgname = orgname;
    }

    public String getPorname() {
        return porname;
    }

    public void setPorname(String porname) {
        this.porname = porname;
    }

    public Date getCtime() {
        return ctime;
    }

    public void setCtime(Date ctime) {
        this.ctime = ctime;
    }

    @Override
    public Date getCreateTime() {
        return createTime;
    }

    @Override
    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Integer getXfllv() {
        return xfllv;
    }

    public void setXfllv(Integer xfllv) {
        this.xfllv = xfllv;
    }

    public BigDecimal getContractmny() {
        return contractmny;
    }

    public void setContractmny(BigDecimal contractmny) {
        this.contractmny = contractmny;
    }

    public BigDecimal getNoinpromny() {
        return noinpromny;
    }

    public void setNoinpromny(BigDecimal noinpromny) {
        this.noinpromny = noinpromny;
    }

    public BigDecimal getXfl() {
        return xfl;
    }

    public void setXfl(BigDecimal xfl) {
        this.xfl = xfl;
    }

    public BigDecimal getMbmny() {
        return mbmny;
    }

    public void setMbmny(BigDecimal mbmny) {
        this.mbmny = mbmny;
    }

    public BigDecimal getRgfcostmny() {
        return rgfcostmny;
    }

    public void setRgfcostmny(BigDecimal rgfcostmny) {
        this.rgfcostmny = rgfcostmny;
    }

    public BigDecimal getClfcostmny() {
        return clfcostmny;
    }

    public void setClfcostmny(BigDecimal clfcostmny) {
        this.clfcostmny = clfcostmny;
    }

    public BigDecimal getSbfcostmny() {
        return sbfcostmny;
    }

    public void setSbfcostmny(BigDecimal sbfcostmny) {
        this.sbfcostmny = sbfcostmny;
    }

    public BigDecimal getZyfbcostmny() {
        return zyfbcostmny;
    }

    public void setZyfbcostmny(BigDecimal zyfbcostmny) {
        this.zyfbcostmny = zyfbcostmny;
    }

    public BigDecimal getQtzccostmny() {
        return qtzccostmny;
    }

    public void setQtzccostmny(BigDecimal qtzccostmny) {
        this.qtzccostmny = qtzccostmny;
    }

    public BigDecimal getJjfcostmny() {
        return jjfcostmny;
    }

    public void setJjfcostmny(BigDecimal jjfcostmny) {
        this.jjfcostmny = jjfcostmny;
    }

    public BigDecimal getSjcostmny() {
        return sjcostmny;
    }

    public void setSjcostmny(BigDecimal sjcostmny) {
        this.sjcostmny = sjcostmny;
    }

    public BigDecimal getZhijiefeiheji() {
        return zhijiefeiheji;
    }

    public void setZhijiefeiheji(BigDecimal zhijiefeiheji) {
        this.zhijiefeiheji = zhijiefeiheji;
    }

    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
}
